@@ -939,7 +939,7 @@ def fill_jac_single(x_res, args):
 
         args_i = args_i + kSize
         out_i = out_i + nCameras * kSize
-        
+
         # A
         # assumes no skew!
         ASize_use = int(ASize / 2)
@@ -963,7 +963,7 @@ def fill_jac_single(x_res, args):
                                               M_use, m_use, delta_use,
                                               resPerCam_single[i_camera])
             obj_fcn_jac_val_y[mask, i + out_i + i_camera * ASize + ASize_use] = df_dx
-            
+
         args_i = args_i + ASize
 
         for i in range(0, rSize, 1):
@@ -1028,20 +1028,21 @@ def fill_jac_single(x_res, args):
 
     return obj_fcn_jac_val
 
-def save_multicalibration_to_matlabcode(result,path):
-    resultPath_text = path + '/multicalibration_matlab_mcl_gen.m'
 
-    f = open(resultPath_text, 'w')
+def save_multicalibration_to_matlabcode(result,path):
+    result_path_text = path + '/multicalibration_matlab_mcl_gen.m'
+
+    f = open(result_path_text, 'w')
 
     f.write('% INFO:\n')
-    f.write('% line break: \ n \n')
-    f.write('% useful webpage: https://docs.opencv.org/2.4/modules/calib3d/doc/camera_calibration_and_3d_reconstruction.html\n')
+    f.write('% line break: \n \n')
+    f.write('% See: https://docs.opencv.org/2.4/modules/calib3d/doc/camera_calibration_and_3d_reconstruction.html\n')
     f.write('\n\n\n')
 
     i = 'nCameras'
-    nCams = result[i]
+    n_cams = result[i]
     f.write('% number of cameras:\n')
-    f.write('nCams = {:01d}\n'.format(nCams))
+    f.write('nCams = {:01d}\n'.format(n_cams))
     f.write('\n\n')
 
     i = 'recFileNames'
@@ -1061,10 +1062,10 @@ def save_multicalibration_to_matlabcode(result,path):
     data_use = result[i]
     f.write('% camera matrices [f_x, c_x, f_y, c_y]:\n')
     f.write('A = [ ...\n')
-    for i_cam in range(nCams):
+    for i_cam in range(n_cams):
         for i_row in range(4):
             f.write(str(data_use[i_cam, i_row]) + ' ')
-        if (i_cam != nCams - 1):
+        if i_cam != n_cams - 1:
             f.write('; ...\n')
         else:
             f.write(']\n')
@@ -1074,10 +1075,10 @@ def save_multicalibration_to_matlabcode(result,path):
     data_use = result[i]
     f.write('% distortion coefficients [k_1, k_2, p_1, p_2, k_3]:\n')
     f.write('k = [ ...\n')
-    for i_cam in range(nCams):
+    for i_cam in range(n_cams):
         for i_row in range(5):
             f.write(str(data_use[i_cam, i_row]) + ' ')
-        if (i_cam != nCams - 1):
+        if i_cam != n_cams - 1:
             f.write('; ...\n')
         else:
             f.write(']\n')
@@ -1087,15 +1088,15 @@ def save_multicalibration_to_matlabcode(result,path):
     data_use = result[i]
     f.write('% rotation matrices to convert into coordinate system of the respective camera:\n')
     f.write('R = cat(3, ...\n')
-    for i_cam in range(nCams):
+    for i_cam in range(n_cams):
         f.write('[')
         for i_row in range(3):
             for i_col in range(3):
                 f.write(str(data_use[i_cam, i_row, i_col]) + ' ')
-            if (i_row != 2):
+            if i_row != 2:
                 f.write('; ...\n')
             else:
-                if (i_cam != nCams - 1):
+                if i_cam != n_cams - 1:
                     f.write('], ...\n')
                 else:
                     f.write('])\n')
@@ -1105,10 +1106,10 @@ def save_multicalibration_to_matlabcode(result,path):
     data_use = result[i]
     f.write('% translation vectors to convert into coordinate system of the respective camera (units in squares):\n')
     f.write('t = [ ...\n')
-    for i_cam in range(nCams):
+    for i_cam in range(n_cams):
         for i_row in range(3):
             f.write(str(data_use[i_cam, i_row]) + ' ')
-        if (i_cam != nCams - 1):
+        if i_cam != n_cams - 1:
             f.write('; ...\n')
         else:
             f.write(']\'\n')
@@ -1116,49 +1117,49 @@ def save_multicalibration_to_matlabcode(result,path):
 
     i = 'headers'
     data_use = result[i]
-    
+
     f.write('% sensor size in pixel:\n')
     f.write('sensorSize = [ ...\n')
-    for i_cam in range(nCams):
+    for i_cam in range(n_cams):
         for i_row in range(2):
             f.write(str(data_use[i_cam]['sensorsize'][i_row]) + ' ')
-        if (i_cam != nCams - 1):
+        if i_cam != n_cams - 1:
             f.write('; ...\n')
         else:
             f.write(']\n')
     f.write('\n\n')
-    
+
     f.write('% offset in pixel:\n')
     f.write('offset = [ ...\n')
-    for i_cam in range(nCams):
+    for i_cam in range(n_cams):
         for i_row in range(2):
             f.write(str(data_use[i_cam]['offset'][i_row]) + ' ')
-        if (i_cam != nCams - 1):
+        if i_cam != n_cams - 1:
             f.write('; ...\n')
         else:
             f.write(']\n')
     f.write('\n\n')
-    
+
     # optional:
-    #f.write('% used width in pixel:\n')
-    #f.write('width = [ ...\n')
-    #for i_cam in range(nCams):
-        #f.write(str(data_use[i_cam]['w']) + ' ')
-        #if (i_cam != nCams - 1):
-            #f.write('; ...\n')
-        #else:
-            #f.write(']\n')
-    #f.write('\n\n')
-    
-    #f.write('% used height in pixel:\n')
-    #f.write('height = [ ...\n')
-    #for i_cam in range(nCams):
-        #f.write(str(data_use[i_cam]['h']) + ' ')
-        #if (i_cam != nCams - 1):
-            #f.write('; ...\n')
-        #else:
-            #f.write(']\n')
-    #f.write('\n\n')
+    # f.write('% used width in pixel:\n')
+    # f.write('width = [ ...\n')
+    # for i_cam in range(nCams):
+    #    f.write(str(data_use[i_cam]['w']) + ' ')
+    #    if (i_cam != nCams - 1):
+    #        f.write('; ...\n')
+    #    else:
+    #        f.write(']\n')
+    # f.write('\n\n')
+    #
+    # f.write('% used height in pixel:\n')
+    # f.write('height = [ ...\n')
+    # for i_cam in range(nCams):
+    #     f.write(str(data_use[i_cam]['h']) + ' ')
+    #     if (i_cam != nCams - 1):
+    #         f.write('; ...\n')
+    #     else:
+    #         f.write(']\n')
+    # f.write('\n\n')
 
     f.write('% square size in cm:\n')
     f.write('square_size = {:.8f}\n'.format(result['square_size_real']))
@@ -1167,14 +1168,19 @@ def save_multicalibration_to_matlabcode(result,path):
     f.write('% marker size in cm:\n')
     f.write('marker_size = {:.8f}\n'.format(result['marker_size_real']))
     f.write('\n\n')
-    
-    f.write('[mc ,mcfn] = cameralib.helper.openCVToMCL(R,t,A,k,sensorSize,square_size,bbohelper.filesystem.filename(f))\n'
-            'mcl = cameralib.MultiCamSetupModel.fromMCL(mcfn)\n'
-            "mcl.save([mcfn(1:end-3) 'mat'])\n"
-            )
+
+    f.write('% scale factor in cm:\n')
+    f.write('scale_factor = {:.8f}\n'.format(result['scale_factor']))
+    f.write('\n\n')
+
+    f.write(
+        "[mc ,mcfn] = cameralib.helper.openCVToMCL(R,t,A,k,sensorSize,scale_factor,bbohelper.filesystem.filename(f))\n"
+        "mcl = cameralib.MultiCamSetupModel.fromMCL(mcfn)\n"
+        "mcl.save([mcfn(1:end-3) 'mat'])\n"
+    )
 
     f.close()
-    print('Saved multi camera calibration to file {:s}'.format(resultPath_text))
+    print('Saved multi camera calibration to file {:s}'.format(result_path_text))
     return
-                
+
 
